==> 0.4.62.tar.gz: lib/controllers/load_more_base_controller.dart <==
import 'package:flutter/foundation.dart';
import 'package:wowit/controllers/base_controller.dart';
import 'package:wowit/widgets/filter_widget/util.dart';
import 'package:wowit/model.dart';
import 'package:wowit/sql_service.dart';

const String fieldPageNumber = 'PageNumber';
const String fieldRowsOfPage = 'RowsOfPage';
const String fieldOrderByField = 'orderByField';
const String fieldOrderByAsc = 'orderByAsc';

abstract class LoadMoreBaseController extends BaseController {
  Map<String, List<Map<String, Object?>?>?> tempData = {};

  int rowsOfPage = -1;

  int _currentPage = 1;
  int get currentPage => _currentPage;

  bool _hasNextPage = true;
  bool get hasNextPage => _hasNextPage;

  bool _isLoadMoreRunning = false;
  bool get isLoadMoreRunning => _isLoadMoreRunning;

  Map<String, Object?> mapCondition = {};

  String? orderByField;
  bool? orderByASC;

  Future<Map<String, List<Map<String, Object>>>> execute(
    String query, {
    Map<String, Object?>? params,
  }) async {
    params ??= {};
    params.addAll({
      fieldPageNumber: _currentPage,
      fieldOrderByField: orderByField,
      fieldOrderByAsc: orderByASC,
    });

    if (rowsOfPage > 0) {
      params.addAll({
        fieldRowsOfPage: rowsOfPage,
      });
    }
    mapCondition.forEach((key, value) {
      if (value != null && value is RangeValue) {
        final giaRangeValue = value;
        params?.update(
          '${key}Min',
          (_) => giaRangeValue.start,
          ifAbsent: () => giaRangeValue.start,
        );
        params?.update(
          '${key}Max',
          (_) => giaRangeValue.end,
          ifAbsent: () => giaRangeValue.end,
        );
      } else {
        params?.update(key, (_) => value, ifAbsent: () => value);
      }
    });

    if (kDebugMode) {
      print('query: $query');
      print('params: $params');
    }

    final data = await SQLService.execute(query, params: params);

    String? displayTable = getFilterFieldName(data);
    if (displayTable == null) {
      _hasNextPage = false;
    } else if (data[displayTable]?.isEmpty ?? true) {
      _hasNextPage = false;
    }

    if (currentPage == 1) {
      tempData.clear();
      tempData.addEntries(data.entries);
    }

    return data;
  }

  void loadMore() async {
    if (hasNextPage && isLoadMoreRunning == false) {
      if (kDebugMode) {
        print('call loadMore: currentPage' +
            currentPage.toString() +
            ', hasNextPage' +
            hasNextPage.toString());
      }

      _currentPage++;
      _isLoadMoreRunning = true;
      update();

      if (kDebugMode) {
        print('$runtimeType load more with page = $currentPage');
      }

      final data = await loadData();
      String? displayTable = getFilterFieldName(data);
      if (displayTable != null) {
        List<Map<String, Object?>?> value = data?[displayTable] ?? [];
        tempData[displayTable]?.addAll(value);
      }
      setData(tempData);

      _isLoadMoreRunning = false;
      update();
    }
  }

  void sort(String orderByField, bool orderByAsc) async {
    this.orderByField = orderByField;
    orderByASC = orderByAsc;
    resetJParam();
    clearData();
    update();
  }

  void filter(Map<String, Object?>? mapCondition) async {
    this.mapCondition = mapCondition ?? {};
    resetJParam();
    clearData();
    update();
  }

  void resetJParam() {
    _currentPage = 1;
    _hasNextPage = true;
    _isLoadMoreRunning = false;
  }
}

==> 0.4.85.tar.gz: lib/controllers/load_more_base_controller.dart <==
import 'package:flutter/foundation.dart';
import 'package:wowit/controllers/base_controller.dart';
import 'package:wowit/widgets/filter_widget/util.dart';
import 'package:wowit/model.dart';
import 'package:wowit/sql_service.dart';

const String fieldPageNumber = 'PageNumber';
const String fieldRowsOfPage = 'RowsOfPage';
const String fieldOrderByField = 'orderByField';
const String fieldOrderByAsc = 'orderByAsc';

abstract class LoadMoreBaseController extends BaseController {
  Map<String, List<Map<String, Object?>?>?> tempData = {};

  int rowsOfPage = -1;

  int _currentPage = 1;
  int get currentPage => _currentPage;

  bool _hasNextPage = true;
  bool get hasNextPage => _hasNextPage;

  bool _isLoadMoreRunning = false;
  bool get isLoadMoreRunning => _isLoadMoreRunning;

  Map<String, Object?> mapCondition = {};

  String? orderByField;
  bool? orderByASC;

  Future<Map<String, List<Map<String, Object?>?>?>?> execute(
    String query, {
    Map<String, Object?>? params,
  }) async {
    params ??= {};
    params.addAll({
      fieldPageNumber: _currentPage,
      fieldOrderByField: orderByField,
      fieldOrderByAsc: orderByASC,
    });

    if (rowsOfPage > 0) {
      params.addAll({
        fieldRowsOfPage: rowsOfPage,
      });
    }
    mapCondition.forEach((key, value) {
      if (value != null && value is RangeValue) {
        final giaRangeValue = value;
        params?.update(
          '${key}Min',
          (_) => giaRangeValue.start,
          ifAbsent: () => giaRangeValue.start,
        );
        params?.update(
          '${key}Max',
          (_) => giaRangeValue.end,
          ifAbsent: () => giaRangeValue.end,
        );
      } else {
        params?.update(key, (_) => value, ifAbsent: () => value);
      }
    });

    if (kDebugMode) {
      print('query: $query');
      print('params: $params');
    }

    final data = await SQLService.execute(query, params: params);

    String? displayTable = getFilterFieldName(data);
    if (displayTable == null) {
      _hasNextPage = false;
    } else if (data[displayTable]?.isEmpty ?? true) {
      _hasNextPage = false;
    }

    if (currentPage == 1) {
      tempData.clear();
      tempData.addEntries(data.entries);
    }

    return data;
  }

  void loadMore() async {
    if (hasNextPage && isLoadMoreRunning == false) {
      if (kDebugMode) {
        print('call loadMore: currentPage' +
            currentPage.toString() +
            ', hasNextPage' +
            hasNextPage.toString());
      }

      _currentPage++;
      _isLoadMoreRunning = true;
      update();

      if (kDebugMode) {
        print('$runtimeType load more with page = $currentPage');
      }

      final data = await loadData();
      String? displayTable = getFilterFieldName(data);
      if (displayTable != null) {
        List<Map<String, Object?>?> value = data?[displayTable] ?? [];
        tempData[displayTable]?.addAll(value);
      }
      setData(tempData);

      _isLoadMoreRunning = false;
      update();
    }
  }

  void sort(String orderByField, bool orderByAsc) async {
    this.orderByField = orderByField;
    orderByASC = orderByAsc;
    resetJParam();
    clearData();
    update();
  }

  void filter(Map<String, Object?>? mapCondition) async {
    this.mapCondition = mapCondition ?? {};
    resetJParam();
    clearData();
    update();
  }

  void resetJParam() {
    _currentPage = 1;
    _hasNextPage = true;
    _isLoadMoreRunning = false;
  }
}
